==> heptapod-rails-0.20.5.tar.gz: heptapod-rails-0.20.5/spec/rubocop/cop/migration/remove_column_spec.rb <==
# frozen_string_literal: true

require 'fast_spec_helper'
require 'rubocop'
require_relative '../../../../rubocop/cop/migration/remove_column'

RSpec.describe RuboCop::Cop::Migration::RemoveColumn do
  include CopHelper

  subject(:cop) { described_class.new }

  def source(meth = 'change')
    "def #{meth}; remove_column :table, :column; end"
  end

  context 'in a regular migration' do
    before do
      allow(cop).to receive(:in_migration?).and_return(true)
      allow(cop).to receive(:in_post_deployment_migration?).and_return(false)
    end

    it 'registers an offense when remove_column is used in the change method' do
      inspect_source(source('change'))

      aggregate_failures do
        expect(cop.offenses.size).to eq(1)
        expect(cop.offenses.map(&:line)).to eq([1])
      end
    end

    it 'registers an offense when remove_column is used in the up method' do
      inspect_source(source('up'))

      aggregate_failures do
        expect(cop.offenses.size).to eq(1)
        expect(cop.offenses.map(&:line)).to eq([1])
      end
    end

    it 'registers no offense when remove_column is used in the down method' do
      inspect_source(source('down'))

      expect(cop.offenses.size).to eq(0)
    end
  end

  context 'in a post-deployment migration' do
    before do
      allow(cop).to receive(:in_migration?).and_return(true)
      allow(cop).to receive(:in_post_deployment_migration?).and_return(true)
    end

    it 'registers no offense' do
      inspect_source(source)

      expect(cop.offenses.size).to eq(0)
    end
  end

  context 'outside of a migration' do
    it 'registers no offense' do
      inspect_source(source)

      expect(cop.offenses.size).to eq(0)
    end
  end
end

==> heptapod-rails-0.24.0rc1.tar.gz: heptapod-rails-0.24.0rc1/spec/rubocop/cop/migration/remove_column_spec.rb <==
# frozen_string_literal: true

require 'fast_spec_helper'
require_relative '../../../../rubocop/cop/migration/remove_column'

RSpec.describe RuboCop::Cop::Migration::RemoveColumn do
  subject(:cop) { described_class.new }

  def source(meth = 'change')
    "def #{meth}; remove_column :table, :column; end"
  end

  context 'when in a regular migration' do
    before do
      allow(cop).to receive(:in_migration?).and_return(true)
      allow(cop).to receive(:in_post_deployment_migration?).and_return(false)
    end

    it 'registers an offense when remove_column is used in the change method' do
      expect_offense(<<~RUBY)
        def change
          remove_column :table, :column
          ^^^^^^^^^^^^^ `remove_column` must only be used in post-deployment migrations
        end
      RUBY
    end

    it 'registers an offense when remove_column is used in the up method' do
      expect_offense(<<~RUBY)
        def up
          remove_column :table, :column
          ^^^^^^^^^^^^^ `remove_column` must only be used in post-deployment migrations
        end
      RUBY
    end

    it 'registers no offense when remove_column is used in the down method' do
      expect_no_offenses(source('down'))
    end
  end

  context 'when in a post-deployment migration' do
    before do
      allow(cop).to receive(:in_migration?).and_return(true)
      allow(cop).to receive(:in_post_deployment_migration?).and_return(true)
    end

    it 'registers no offense' do
      expect_no_offenses(source)
    end
  end

  context 'when outside of a migration' do
    it 'registers no offense' do
      expect_no_offenses(source)
    end
  end
end
